@@ -5,14 +5,18 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.37.3")
+(defparameter *autoconf-version* "5.38.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
 (defparameter *autoconf-host* "armv7l-unknown-linux-gnueabihf")
+;; This variable is kept for backwards compatibiliy reasons:
+;; We seem to be in the fortunate position that we sometimes need to check for windows.
+;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
+(defparameter *autoconf-windows* "false")
 (defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
  
-(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.37.3")
+(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.38.0")
 (defparameter *maxima-default-layout-autotools* "true")
